You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@hc.apache.org by ol...@apache.org on 2015/11/21 17:53:03 UTC

svn commit: r1715545 [7/10] - in /httpcomponents/httpcore/trunk: httpcore-ab/ httpcore-ab/src/main/java/org/apache/hc/ httpcore-ab/src/main/java/org/apache/hc/core5/ httpcore-ab/src/main/java/org/apache/hc/core5/http/ httpcore-ab/src/main/java/org/apac...

Modified: httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/StatusLine.java
URL: http://svn.apache.org/viewvc/httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/StatusLine.java?rev=1715545&r1=1715521&r2=1715545&view=diff
==============================================================================
--- httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/StatusLine.java (original)
+++ httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/StatusLine.java Sat Nov 21 16:52:56 2015
@@ -25,7 +25,7 @@
  *
  */
 
-package org.apache.http;
+package org.apache.hc.core5.http;
 
 /**
  * The first line of a Response message is the Status-Line, consisting

Modified: httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/TrailerSupplier.java
URL: http://svn.apache.org/viewvc/httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/TrailerSupplier.java?rev=1715545&r1=1715521&r2=1715545&view=diff
==============================================================================
--- httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/TrailerSupplier.java (original)
+++ httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/TrailerSupplier.java Sat Nov 21 16:52:56 2015
@@ -25,7 +25,7 @@
  *
  */
 
-package org.apache.http;
+package org.apache.hc.core5.http;
 
 /**
  * Supplier of trailing headers to be sent after message body.

Modified: httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/TruncatedChunkException.java
URL: http://svn.apache.org/viewvc/httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/TruncatedChunkException.java?rev=1715545&r1=1715521&r2=1715545&view=diff
==============================================================================
--- httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/TruncatedChunkException.java (original)
+++ httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/TruncatedChunkException.java Sat Nov 21 16:52:56 2015
@@ -25,7 +25,7 @@
  *
  */
 
-package org.apache.http;
+package org.apache.hc.core5.http;
 
 /**
  * Signals a truncated chunk in a chunked stream.

Modified: httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/UnsupportedHttpVersionException.java
URL: http://svn.apache.org/viewvc/httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/UnsupportedHttpVersionException.java?rev=1715545&r1=1715521&r2=1715545&view=diff
==============================================================================
--- httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/UnsupportedHttpVersionException.java (original)
+++ httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/UnsupportedHttpVersionException.java Sat Nov 21 16:52:56 2015
@@ -25,7 +25,7 @@
  *
  */
 
-package org.apache.http;
+package org.apache.hc.core5.http;
 
 /**
  * Signals an unsupported version of the HTTP protocol.

Modified: httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/annotation/Experimental.java
URL: http://svn.apache.org/viewvc/httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/annotation/Experimental.java?rev=1715545&r1=1715521&r2=1715545&view=diff
==============================================================================
--- httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/annotation/Experimental.java (original)
+++ httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/annotation/Experimental.java Sat Nov 21 16:52:56 2015
@@ -24,7 +24,7 @@
  * <http://www.apache.org/>.
  *
  */
-package org.apache.http.annotation;
+package org.apache.hc.core5.http.annotation;
 
 import java.lang.annotation.Documented;
 import java.lang.annotation.ElementType;

Modified: httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/annotation/GuardedBy.java
URL: http://svn.apache.org/viewvc/httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/annotation/GuardedBy.java?rev=1715545&r1=1715521&r2=1715545&view=diff
==============================================================================
--- httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/annotation/GuardedBy.java (original)
+++ httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/annotation/GuardedBy.java Sat Nov 21 16:52:56 2015
@@ -24,7 +24,7 @@
  * <http://www.apache.org/>.
  *
  */
-package org.apache.http.annotation;
+package org.apache.hc.core5.http.annotation;
 
 import java.lang.annotation.Documented;
 import java.lang.annotation.ElementType;

Modified: httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/annotation/Immutable.java
URL: http://svn.apache.org/viewvc/httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/annotation/Immutable.java?rev=1715545&r1=1715521&r2=1715545&view=diff
==============================================================================
--- httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/annotation/Immutable.java (original)
+++ httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/annotation/Immutable.java Sat Nov 21 16:52:56 2015
@@ -24,7 +24,7 @@
  * <http://www.apache.org/>.
  *
  */
-package org.apache.http.annotation;
+package org.apache.hc.core5.http.annotation;
 
 import java.lang.annotation.Documented;
 import java.lang.annotation.ElementType;

Modified: httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/annotation/NotThreadSafe.java
URL: http://svn.apache.org/viewvc/httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/annotation/NotThreadSafe.java?rev=1715545&r1=1715521&r2=1715545&view=diff
==============================================================================
--- httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/annotation/NotThreadSafe.java (original)
+++ httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/annotation/NotThreadSafe.java Sat Nov 21 16:52:56 2015
@@ -24,7 +24,7 @@
  * <http://www.apache.org/>.
  *
  */
-package org.apache.http.annotation;
+package org.apache.hc.core5.http.annotation;
 
 import java.lang.annotation.Documented;
 import java.lang.annotation.ElementType;

Modified: httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/annotation/Obsolete.java
URL: http://svn.apache.org/viewvc/httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/annotation/Obsolete.java?rev=1715545&r1=1715521&r2=1715545&view=diff
==============================================================================
--- httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/annotation/Obsolete.java (original)
+++ httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/annotation/Obsolete.java Sat Nov 21 16:52:56 2015
@@ -24,7 +24,7 @@
  * <http://www.apache.org/>.
  *
  */
-package org.apache.http.annotation;
+package org.apache.hc.core5.http.annotation;
 
 import java.lang.annotation.Documented;
 import java.lang.annotation.ElementType;

Modified: httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/annotation/ThreadSafe.java
URL: http://svn.apache.org/viewvc/httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/annotation/ThreadSafe.java?rev=1715545&r1=1715521&r2=1715545&view=diff
==============================================================================
--- httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/annotation/ThreadSafe.java (original)
+++ httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/annotation/ThreadSafe.java Sat Nov 21 16:52:56 2015
@@ -24,7 +24,7 @@
  * <http://www.apache.org/>.
  *
  */
-package org.apache.http.annotation;
+package org.apache.hc.core5.http.annotation;
 
 import java.lang.annotation.Documented;
 import java.lang.annotation.ElementType;

Modified: httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/annotation/package-info.java
URL: http://svn.apache.org/viewvc/httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/annotation/package-info.java?rev=1715545&r1=1715521&r2=1715545&view=diff
==============================================================================
--- httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/annotation/package-info.java (original)
+++ httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/annotation/package-info.java Sat Nov 21 16:52:56 2015
@@ -32,4 +32,4 @@
  * See http://www.jcip.net
  * </p>
  */
-package org.apache.http.annotation;
+package org.apache.hc.core5.http.annotation;

Modified: httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/concurrent/BasicFuture.java
URL: http://svn.apache.org/viewvc/httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/concurrent/BasicFuture.java?rev=1715545&r1=1715521&r2=1715545&view=diff
==============================================================================
--- httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/concurrent/BasicFuture.java (original)
+++ httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/concurrent/BasicFuture.java Sat Nov 21 16:52:56 2015
@@ -24,9 +24,9 @@
  * <http://www.apache.org/>.
  *
  */
-package org.apache.http.concurrent;
+package org.apache.hc.core5.http.concurrent;
 
-import org.apache.http.util.Args;
+import org.apache.hc.core5.http.util.Args;
 
 import java.util.concurrent.ExecutionException;
 import java.util.concurrent.Future;

Modified: httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/concurrent/Cancellable.java
URL: http://svn.apache.org/viewvc/httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/concurrent/Cancellable.java?rev=1715545&r1=1715521&r2=1715545&view=diff
==============================================================================
--- httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/concurrent/Cancellable.java (original)
+++ httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/concurrent/Cancellable.java Sat Nov 21 16:52:56 2015
@@ -24,7 +24,7 @@
  * <http://www.apache.org/>.
  *
  */
-package org.apache.http.concurrent;
+package org.apache.hc.core5.http.concurrent;
 
 /**
  * A {@code Cancellable} represents a process or an operation that can be

Modified: httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/concurrent/FutureCallback.java
URL: http://svn.apache.org/viewvc/httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/concurrent/FutureCallback.java?rev=1715545&r1=1715521&r2=1715545&view=diff
==============================================================================
--- httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/concurrent/FutureCallback.java (original)
+++ httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/concurrent/FutureCallback.java Sat Nov 21 16:52:56 2015
@@ -24,7 +24,7 @@
  * <http://www.apache.org/>.
  *
  */
-package org.apache.http.concurrent;
+package org.apache.hc.core5.http.concurrent;
 
 /**
  * A callback interface that gets invoked upon completion of

Modified: httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/concurrent/package-info.java
URL: http://svn.apache.org/viewvc/httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/concurrent/package-info.java?rev=1715545&r1=1715521&r2=1715545&view=diff
==============================================================================
--- httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/concurrent/package-info.java (original)
+++ httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/concurrent/package-info.java Sat Nov 21 16:52:56 2015
@@ -28,4 +28,4 @@
 /**
  * Core concurrency APIs.
  */
-package org.apache.http.concurrent;
+package org.apache.hc.core5.http.concurrent;

Modified: httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/config/ConnectionConfig.java
URL: http://svn.apache.org/viewvc/httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/config/ConnectionConfig.java?rev=1715545&r1=1715521&r2=1715545&view=diff
==============================================================================
--- httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/config/ConnectionConfig.java (original)
+++ httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/config/ConnectionConfig.java Sat Nov 21 16:52:56 2015
@@ -25,14 +25,14 @@
  *
  */
 
-package org.apache.http.config;
+package org.apache.hc.core5.http.config;
 
 import java.nio.charset.Charset;
 import java.nio.charset.CodingErrorAction;
 
-import org.apache.http.Consts;
-import org.apache.http.annotation.Immutable;
-import org.apache.http.util.Args;
+import org.apache.hc.core5.http.Consts;
+import org.apache.hc.core5.http.annotation.Immutable;
+import org.apache.hc.core5.http.util.Args;
 
 /**
  * HTTP connection configuration.

Modified: httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/config/Lookup.java
URL: http://svn.apache.org/viewvc/httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/config/Lookup.java?rev=1715545&r1=1715521&r2=1715545&view=diff
==============================================================================
--- httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/config/Lookup.java (original)
+++ httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/config/Lookup.java Sat Nov 21 16:52:56 2015
@@ -25,7 +25,7 @@
  *
  */
 
-package org.apache.http.config;
+package org.apache.hc.core5.http.config;
 
 
 /**

Modified: httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/config/MessageConstraints.java
URL: http://svn.apache.org/viewvc/httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/config/MessageConstraints.java?rev=1715545&r1=1715521&r2=1715545&view=diff
==============================================================================
--- httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/config/MessageConstraints.java (original)
+++ httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/config/MessageConstraints.java Sat Nov 21 16:52:56 2015
@@ -25,9 +25,9 @@
  *
  */
 
-package org.apache.http.config;
+package org.apache.hc.core5.http.config;
 
-import org.apache.http.util.Args;
+import org.apache.hc.core5.http.util.Args;
 
 /**
  * HTTP Message constraints: line length and header count.

Modified: httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/config/Registry.java
URL: http://svn.apache.org/viewvc/httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/config/Registry.java?rev=1715545&r1=1715521&r2=1715545&view=diff
==============================================================================
--- httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/config/Registry.java (original)
+++ httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/config/Registry.java Sat Nov 21 16:52:56 2015
@@ -25,13 +25,13 @@
  *
  */
 
-package org.apache.http.config;
+package org.apache.hc.core5.http.config;
 
 import java.util.Locale;
 import java.util.Map;
 import java.util.concurrent.ConcurrentHashMap;
 
-import org.apache.http.annotation.ThreadSafe;
+import org.apache.hc.core5.http.annotation.ThreadSafe;
 
 /**
  * Generic registry of items keyed by low-case string ID.

Modified: httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/config/RegistryBuilder.java
URL: http://svn.apache.org/viewvc/httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/config/RegistryBuilder.java?rev=1715545&r1=1715521&r2=1715545&view=diff
==============================================================================
--- httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/config/RegistryBuilder.java (original)
+++ httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/config/RegistryBuilder.java Sat Nov 21 16:52:56 2015
@@ -25,14 +25,14 @@
  *
  */
 
-package org.apache.http.config;
+package org.apache.hc.core5.http.config;
 
 import java.util.HashMap;
 import java.util.Locale;
 import java.util.Map;
 
-import org.apache.http.annotation.NotThreadSafe;
-import org.apache.http.util.Args;
+import org.apache.hc.core5.http.annotation.NotThreadSafe;
+import org.apache.hc.core5.http.util.Args;
 
 /**
  * Builder for {@link Registry} instances.

Modified: httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/config/SocketConfig.java
URL: http://svn.apache.org/viewvc/httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/config/SocketConfig.java?rev=1715545&r1=1715521&r2=1715545&view=diff
==============================================================================
--- httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/config/SocketConfig.java (original)
+++ httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/config/SocketConfig.java Sat Nov 21 16:52:56 2015
@@ -25,10 +25,10 @@
  *
  */
 
-package org.apache.http.config;
+package org.apache.hc.core5.http.config;
 
-import org.apache.http.annotation.Immutable;
-import org.apache.http.util.Args;
+import org.apache.hc.core5.http.annotation.Immutable;
+import org.apache.hc.core5.http.util.Args;
 
 /**
  * Socket configuration.

Modified: httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/config/package-info.java
URL: http://svn.apache.org/viewvc/httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/config/package-info.java?rev=1715545&r1=1715521&r2=1715545&view=diff
==============================================================================
--- httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/config/package-info.java (original)
+++ httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/config/package-info.java Sat Nov 21 16:52:56 2015
@@ -28,4 +28,4 @@
 /**
  * Core configuration APIs.
  */
-package org.apache.http.config;
+package org.apache.hc.core5.http.config;

Modified: httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/entity/AbstractHttpEntity.java
URL: http://svn.apache.org/viewvc/httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/entity/AbstractHttpEntity.java?rev=1715545&r1=1715521&r2=1715545&view=diff
==============================================================================
--- httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/entity/AbstractHttpEntity.java (original)
+++ httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/entity/AbstractHttpEntity.java Sat Nov 21 16:52:56 2015
@@ -25,13 +25,13 @@
  *
  */
 
-package org.apache.http.entity;
+package org.apache.hc.core5.http.entity;
 
 import java.util.Collections;
 import java.util.Set;
 
-import org.apache.http.TrailerSupplier;
-import org.apache.http.annotation.NotThreadSafe;
+import org.apache.hc.core5.http.TrailerSupplier;
+import org.apache.hc.core5.http.annotation.NotThreadSafe;
 
 /**
  * Abstract base class for mutable entities. Provides the commonly used attributes for streamed and

Modified: httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/entity/AbstractImmutableHttpEntity.java
URL: http://svn.apache.org/viewvc/httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/entity/AbstractImmutableHttpEntity.java?rev=1715545&r1=1715521&r2=1715545&view=diff
==============================================================================
--- httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/entity/AbstractImmutableHttpEntity.java (original)
+++ httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/entity/AbstractImmutableHttpEntity.java Sat Nov 21 16:52:56 2015
@@ -25,15 +25,15 @@
  *
  */
 
-package org.apache.http.entity;
+package org.apache.hc.core5.http.entity;
 
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
 
-import org.apache.http.HttpEntity;
-import org.apache.http.annotation.NotThreadSafe;
-import org.apache.http.util.Args;
+import org.apache.hc.core5.http.HttpEntity;
+import org.apache.hc.core5.http.annotation.NotThreadSafe;
+import org.apache.hc.core5.http.util.Args;
 
 /**
  * Abstract base class for immutable entities.

Modified: httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/entity/BasicHttpEntity.java
URL: http://svn.apache.org/viewvc/httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/entity/BasicHttpEntity.java?rev=1715545&r1=1715521&r2=1715545&view=diff
==============================================================================
--- httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/entity/BasicHttpEntity.java (original)
+++ httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/entity/BasicHttpEntity.java Sat Nov 21 16:52:56 2015
@@ -25,13 +25,13 @@
  *
  */
 
-package org.apache.http.entity;
+package org.apache.hc.core5.http.entity;
 
 import java.io.InputStream;
 
-import org.apache.http.annotation.NotThreadSafe;
-import org.apache.http.impl.io.EmptyInputStream;
-import org.apache.http.util.Asserts;
+import org.apache.hc.core5.http.annotation.NotThreadSafe;
+import org.apache.hc.core5.http.impl.io.EmptyInputStream;
+import org.apache.hc.core5.http.util.Asserts;
 
 /**
  * A generic streamed, non-repeatable entity that obtains its content

Modified: httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/entity/BufferedHttpEntity.java
URL: http://svn.apache.org/viewvc/httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/entity/BufferedHttpEntity.java?rev=1715545&r1=1715521&r2=1715545&view=diff
==============================================================================
--- httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/entity/BufferedHttpEntity.java (original)
+++ httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/entity/BufferedHttpEntity.java Sat Nov 21 16:52:56 2015
@@ -25,7 +25,7 @@
  *
  */
 
-package org.apache.http.entity;
+package org.apache.hc.core5.http.entity;
 
 import java.io.ByteArrayInputStream;
 import java.io.ByteArrayOutputStream;
@@ -33,9 +33,9 @@ import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
 
-import org.apache.http.HttpEntity;
-import org.apache.http.annotation.NotThreadSafe;
-import org.apache.http.util.Args;
+import org.apache.hc.core5.http.HttpEntity;
+import org.apache.hc.core5.http.annotation.NotThreadSafe;
+import org.apache.hc.core5.http.util.Args;
 
 /**
  * A wrapping entity that buffers it content if necessary.

Modified: httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/entity/ByteArrayEntity.java
URL: http://svn.apache.org/viewvc/httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/entity/ByteArrayEntity.java?rev=1715545&r1=1715521&r2=1715545&view=diff
==============================================================================
--- httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/entity/ByteArrayEntity.java (original)
+++ httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/entity/ByteArrayEntity.java Sat Nov 21 16:52:56 2015
@@ -25,15 +25,15 @@
  *
  */
 
-package org.apache.http.entity;
+package org.apache.hc.core5.http.entity;
 
 import java.io.ByteArrayInputStream;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
 
-import org.apache.http.annotation.NotThreadSafe;
-import org.apache.http.util.Args;
+import org.apache.hc.core5.http.annotation.NotThreadSafe;
+import org.apache.hc.core5.http.util.Args;
 
 /**
  * A self contained, repeatable entity that obtains its content from a byte array.

Modified: httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/entity/ByteBufferEntity.java
URL: http://svn.apache.org/viewvc/httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/entity/ByteBufferEntity.java?rev=1715545&r1=1715521&r2=1715545&view=diff
==============================================================================
--- httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/entity/ByteBufferEntity.java (original)
+++ httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/entity/ByteBufferEntity.java Sat Nov 21 16:52:56 2015
@@ -25,7 +25,7 @@
  *
  */
 
-package org.apache.http.entity;
+package org.apache.hc.core5.http.entity;
 
 import java.io.IOException;
 import java.io.InputStream;
@@ -34,8 +34,8 @@ import java.nio.ByteBuffer;
 import java.nio.channels.Channels;
 import java.nio.channels.WritableByteChannel;
 
-import org.apache.http.annotation.NotThreadSafe;
-import org.apache.http.util.Args;
+import org.apache.hc.core5.http.annotation.NotThreadSafe;
+import org.apache.hc.core5.http.util.Args;
 
 /**
  * An entity that delivers the contents of a {@link ByteBuffer}.

Modified: httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/entity/ContentLengthStrategy.java
URL: http://svn.apache.org/viewvc/httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/entity/ContentLengthStrategy.java?rev=1715545&r1=1715521&r2=1715545&view=diff
==============================================================================
--- httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/entity/ContentLengthStrategy.java (original)
+++ httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/entity/ContentLengthStrategy.java Sat Nov 21 16:52:56 2015
@@ -25,10 +25,10 @@
  *
  */
 
-package org.apache.http.entity;
+package org.apache.hc.core5.http.entity;
 
-import org.apache.http.HttpException;
-import org.apache.http.HttpMessage;
+import org.apache.hc.core5.http.HttpException;
+import org.apache.hc.core5.http.HttpMessage;
 
 /**
  * Represents a strategy to determine length of the enclosed content entity

Modified: httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/entity/ContentType.java
URL: http://svn.apache.org/viewvc/httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/entity/ContentType.java?rev=1715545&r1=1715521&r2=1715545&view=diff
==============================================================================
--- httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/entity/ContentType.java (original)
+++ httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/entity/ContentType.java Sat Nov 21 16:52:56 2015
@@ -25,7 +25,7 @@
  *
  */
 
-package org.apache.http.entity;
+package org.apache.hc.core5.http.entity;
 
 import java.io.Serializable;
 import java.nio.charset.Charset;
@@ -36,18 +36,18 @@ import java.util.List;
 import java.util.Locale;
 import java.util.Map;
 
-import org.apache.http.Consts;
-import org.apache.http.HeaderElement;
-import org.apache.http.HttpEntity;
-import org.apache.http.NameValuePair;
-import org.apache.http.annotation.Immutable;
-import org.apache.http.message.BasicHeaderValueFormatter;
-import org.apache.http.message.BasicHeaderValueParser;
-import org.apache.http.message.BasicNameValuePair;
-import org.apache.http.message.ParserCursor;
-import org.apache.http.util.Args;
-import org.apache.http.util.CharArrayBuffer;
-import org.apache.http.util.TextUtils;
+import org.apache.hc.core5.http.Consts;
+import org.apache.hc.core5.http.HeaderElement;
+import org.apache.hc.core5.http.HttpEntity;
+import org.apache.hc.core5.http.NameValuePair;
+import org.apache.hc.core5.http.annotation.Immutable;
+import org.apache.hc.core5.http.message.BasicHeaderValueFormatter;
+import org.apache.hc.core5.http.message.BasicHeaderValueParser;
+import org.apache.hc.core5.http.message.BasicNameValuePair;
+import org.apache.hc.core5.http.message.ParserCursor;
+import org.apache.hc.core5.http.util.Args;
+import org.apache.hc.core5.http.util.CharArrayBuffer;
+import org.apache.hc.core5.http.util.TextUtils;
 
 /**
  * Content type information consisting of a MIME type and an optional charset.

Modified: httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/entity/FileEntity.java
URL: http://svn.apache.org/viewvc/httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/entity/FileEntity.java?rev=1715545&r1=1715521&r2=1715545&view=diff
==============================================================================
--- httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/entity/FileEntity.java (original)
+++ httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/entity/FileEntity.java Sat Nov 21 16:52:56 2015
@@ -25,15 +25,15 @@
  *
  */
 
-package org.apache.http.entity;
+package org.apache.hc.core5.http.entity;
 
 import java.io.File;
 import java.io.FileInputStream;
 import java.io.IOException;
 import java.io.InputStream;
 
-import org.apache.http.annotation.NotThreadSafe;
-import org.apache.http.util.Args;
+import org.apache.hc.core5.http.annotation.NotThreadSafe;
+import org.apache.hc.core5.http.util.Args;
 
 /**
  * A self contained, repeatable entity that obtains its content from a file.

Modified: httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/entity/HttpContentProducer.java
URL: http://svn.apache.org/viewvc/httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/entity/HttpContentProducer.java?rev=1715545&r1=1715521&r2=1715545&view=diff
==============================================================================
--- httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/entity/HttpContentProducer.java (original)
+++ httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/entity/HttpContentProducer.java Sat Nov 21 16:52:56 2015
@@ -25,7 +25,7 @@
  *
  */
 
-package org.apache.http.entity;
+package org.apache.hc.core5.http.entity;
 
 import java.io.IOException;
 import java.io.OutputStream;

Modified: httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/entity/HttpEntityWithTrailers.java
URL: http://svn.apache.org/viewvc/httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/entity/HttpEntityWithTrailers.java?rev=1715545&r1=1715521&r2=1715545&view=diff
==============================================================================
--- httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/entity/HttpEntityWithTrailers.java (original)
+++ httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/entity/HttpEntityWithTrailers.java Sat Nov 21 16:52:56 2015
@@ -25,7 +25,7 @@
  *
  */
 
-package org.apache.http.entity;
+package org.apache.hc.core5.http.entity;
 
 import java.io.IOException;
 import java.io.InputStream;
@@ -33,11 +33,11 @@ import java.io.OutputStream;
 import java.util.LinkedHashSet;
 import java.util.Set;
 
-import org.apache.http.Header;
-import org.apache.http.HttpEntity;
-import org.apache.http.TrailerSupplier;
-import org.apache.http.annotation.NotThreadSafe;
-import org.apache.http.util.Args;
+import org.apache.hc.core5.http.Header;
+import org.apache.hc.core5.http.HttpEntity;
+import org.apache.hc.core5.http.TrailerSupplier;
+import org.apache.hc.core5.http.annotation.NotThreadSafe;
+import org.apache.hc.core5.http.util.Args;
 
 /**
  * Wrapping entity that also includes trailers.

Modified: httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/entity/HttpEntityWrapper.java
URL: http://svn.apache.org/viewvc/httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/entity/HttpEntityWrapper.java?rev=1715545&r1=1715521&r2=1715545&view=diff
==============================================================================
--- httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/entity/HttpEntityWrapper.java (original)
+++ httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/entity/HttpEntityWrapper.java Sat Nov 21 16:52:56 2015
@@ -25,17 +25,17 @@
  *
  */
 
-package org.apache.http.entity;
+package org.apache.hc.core5.http.entity;
 
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
 import java.util.Set;
 
-import org.apache.http.HttpEntity;
-import org.apache.http.TrailerSupplier;
-import org.apache.http.annotation.NotThreadSafe;
-import org.apache.http.util.Args;
+import org.apache.hc.core5.http.HttpEntity;
+import org.apache.hc.core5.http.TrailerSupplier;
+import org.apache.hc.core5.http.annotation.NotThreadSafe;
+import org.apache.hc.core5.http.util.Args;
 
 /**
  * Base class for wrapping entities.

Modified: httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/entity/InputStreamEntity.java
URL: http://svn.apache.org/viewvc/httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/entity/InputStreamEntity.java?rev=1715545&r1=1715521&r2=1715545&view=diff
==============================================================================
--- httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/entity/InputStreamEntity.java (original)
+++ httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/entity/InputStreamEntity.java Sat Nov 21 16:52:56 2015
@@ -25,14 +25,14 @@
  *
  */
 
-package org.apache.http.entity;
+package org.apache.hc.core5.http.entity;
 
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
 
-import org.apache.http.annotation.NotThreadSafe;
-import org.apache.http.util.Args;
+import org.apache.hc.core5.http.annotation.NotThreadSafe;
+import org.apache.hc.core5.http.util.Args;
 
 /**
  * A streamed, non-repeatable entity that obtains its content from

Modified: httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/entity/SerializableEntity.java
URL: http://svn.apache.org/viewvc/httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/entity/SerializableEntity.java?rev=1715545&r1=1715521&r2=1715545&view=diff
==============================================================================
--- httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/entity/SerializableEntity.java (original)
+++ httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/entity/SerializableEntity.java Sat Nov 21 16:52:56 2015
@@ -25,7 +25,7 @@
  *
  */
 
-package org.apache.http.entity;
+package org.apache.hc.core5.http.entity;
 
 import java.io.ByteArrayInputStream;
 import java.io.ByteArrayOutputStream;
@@ -35,8 +35,8 @@ import java.io.ObjectOutputStream;
 import java.io.OutputStream;
 import java.io.Serializable;
 
-import org.apache.http.annotation.NotThreadSafe;
-import org.apache.http.util.Args;
+import org.apache.hc.core5.http.annotation.NotThreadSafe;
+import org.apache.hc.core5.http.util.Args;
 
 /**
  * A streamed entity that obtains its content from a {@link Serializable}.

Modified: httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/entity/StringEntity.java
URL: http://svn.apache.org/viewvc/httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/entity/StringEntity.java?rev=1715545&r1=1715521&r2=1715545&view=diff
==============================================================================
--- httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/entity/package-info.java (original)
+++ httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/entity/package-info.java Sat Nov 21 16:52:56 2015
@@ -28,4 +28,4 @@
 /**
  * Core HTTP entity implementations.
  */
-package org.apache.http.entity;
+package org.apache.hc.core5.http.entity;

Modified: httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/BHttpConnectionBase.java
URL: http://svn.apache.org/viewvc/httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/BHttpConnectionBase.java?rev=1715545&r1=1715521&r2=1715545&view=diff
==============================================================================
--- httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/BHttpConnectionBase.java (original)
+++ httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/BHttpConnectionBase.java Sat Nov 21 16:52:56 2015
@@ -25,7 +25,7 @@
  *
  */
 
-package org.apache.http.impl;
+package org.apache.hc.core5.http.impl;
 
 import java.io.IOException;
 import java.io.InputStream;
@@ -38,30 +38,30 @@ import java.nio.charset.CharsetDecoder;
 import java.nio.charset.CharsetEncoder;
 import java.util.concurrent.atomic.AtomicReference;
 
-import org.apache.http.BHttpConnection;
-import org.apache.http.ConnectionClosedException;
-import org.apache.http.HttpConnectionMetrics;
-import org.apache.http.HttpEntity;
-import org.apache.http.HttpException;
-import org.apache.http.HttpHeaders;
-import org.apache.http.HttpMessage;
-import org.apache.http.TrailerSupplier;
-import org.apache.http.config.MessageConstraints;
-import org.apache.http.entity.ContentLengthStrategy;
-import org.apache.http.impl.io.ChunkedInputStream;
-import org.apache.http.impl.io.ChunkedOutputStream;
-import org.apache.http.impl.io.ContentLengthInputStream;
-import org.apache.http.impl.io.ContentLengthOutputStream;
-import org.apache.http.impl.io.EmptyInputStream;
-import org.apache.http.impl.io.HttpTransportMetricsImpl;
-import org.apache.http.impl.io.IdentityInputStream;
-import org.apache.http.impl.io.IdentityOutputStream;
-import org.apache.http.impl.io.SessionInputBufferImpl;
-import org.apache.http.impl.io.SessionOutputBufferImpl;
-import org.apache.http.io.SessionInputBuffer;
-import org.apache.http.io.SessionOutputBuffer;
-import org.apache.http.util.Args;
-import org.apache.http.util.NetUtils;
+import org.apache.hc.core5.http.BHttpConnection;
+import org.apache.hc.core5.http.ConnectionClosedException;
+import org.apache.hc.core5.http.HttpConnectionMetrics;
+import org.apache.hc.core5.http.HttpEntity;
+import org.apache.hc.core5.http.HttpException;
+import org.apache.hc.core5.http.HttpHeaders;
+import org.apache.hc.core5.http.HttpMessage;
+import org.apache.hc.core5.http.TrailerSupplier;
+import org.apache.hc.core5.http.config.MessageConstraints;
+import org.apache.hc.core5.http.entity.ContentLengthStrategy;
+import org.apache.hc.core5.http.impl.io.ChunkedInputStream;
+import org.apache.hc.core5.http.impl.io.ChunkedOutputStream;
+import org.apache.hc.core5.http.impl.io.ContentLengthInputStream;
+import org.apache.hc.core5.http.impl.io.ContentLengthOutputStream;
+import org.apache.hc.core5.http.impl.io.EmptyInputStream;
+import org.apache.hc.core5.http.impl.io.HttpTransportMetricsImpl;
+import org.apache.hc.core5.http.impl.io.IdentityInputStream;
+import org.apache.hc.core5.http.impl.io.IdentityOutputStream;
+import org.apache.hc.core5.http.impl.io.SessionInputBufferImpl;
+import org.apache.hc.core5.http.impl.io.SessionOutputBufferImpl;
+import org.apache.hc.core5.http.io.SessionInputBuffer;
+import org.apache.hc.core5.http.io.SessionOutputBuffer;
+import org.apache.hc.core5.http.util.Args;
+import org.apache.hc.core5.http.util.NetUtils;
 
 class BHttpConnectionBase implements BHttpConnection {
 

Modified: httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/ConnSupport.java
URL: http://svn.apache.org/viewvc/httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/ConnSupport.java?rev=1715545&r1=1715521&r2=1715545&view=diff
==============================================================================
--- httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/ConnSupport.java (original)
+++ httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/ConnSupport.java Sat Nov 21 16:52:56 2015
@@ -24,9 +24,9 @@
  * <http://www.apache.org/>.
  *
  */
-package org.apache.http.impl;
+package org.apache.hc.core5.http.impl;
 
-import org.apache.http.config.ConnectionConfig;
+import org.apache.hc.core5.http.config.ConnectionConfig;
 
 import java.nio.charset.Charset;
 import java.nio.charset.CharsetDecoder;

Modified: httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/DefaultBHttpClientConnection.java
URL: http://svn.apache.org/viewvc/httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/DefaultBHttpClientConnection.java?rev=1715545&r1=1715521&r2=1715545&view=diff
==============================================================================
--- httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/DefaultBHttpClientConnection.java (original)
+++ httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/DefaultBHttpClientConnection.java Sat Nov 21 16:52:56 2015
@@ -25,7 +25,7 @@
  *
  */
 
-package org.apache.http.impl;
+package org.apache.hc.core5.http.impl;
 
 import java.io.IOException;
 import java.io.OutputStream;
@@ -33,24 +33,24 @@ import java.net.Socket;
 import java.nio.charset.CharsetDecoder;
 import java.nio.charset.CharsetEncoder;
 
-import org.apache.http.HttpClientConnection;
-import org.apache.http.HttpEntity;
-import org.apache.http.HttpException;
-import org.apache.http.HttpRequest;
-import org.apache.http.HttpResponse;
-import org.apache.http.HttpStatus;
-import org.apache.http.LengthRequiredException;
-import org.apache.http.annotation.NotThreadSafe;
-import org.apache.http.config.MessageConstraints;
-import org.apache.http.entity.ContentLengthStrategy;
-import org.apache.http.impl.entity.DefaultContentLengthStrategy;
-import org.apache.http.impl.io.DefaultHttpRequestWriterFactory;
-import org.apache.http.impl.io.DefaultHttpResponseParserFactory;
-import org.apache.http.io.HttpMessageParser;
-import org.apache.http.io.HttpMessageParserFactory;
-import org.apache.http.io.HttpMessageWriter;
-import org.apache.http.io.HttpMessageWriterFactory;
-import org.apache.http.util.Args;
+import org.apache.hc.core5.http.HttpClientConnection;
+import org.apache.hc.core5.http.HttpEntity;
+import org.apache.hc.core5.http.HttpException;
+import org.apache.hc.core5.http.HttpRequest;
+import org.apache.hc.core5.http.HttpResponse;
+import org.apache.hc.core5.http.HttpStatus;
+import org.apache.hc.core5.http.LengthRequiredException;
+import org.apache.hc.core5.http.annotation.NotThreadSafe;
+import org.apache.hc.core5.http.config.MessageConstraints;
+import org.apache.hc.core5.http.entity.ContentLengthStrategy;
+import org.apache.hc.core5.http.impl.entity.DefaultContentLengthStrategy;
+import org.apache.hc.core5.http.impl.io.DefaultHttpRequestWriterFactory;
+import org.apache.hc.core5.http.impl.io.DefaultHttpResponseParserFactory;
+import org.apache.hc.core5.http.io.HttpMessageParser;
+import org.apache.hc.core5.http.io.HttpMessageParserFactory;
+import org.apache.hc.core5.http.io.HttpMessageWriter;
+import org.apache.hc.core5.http.io.HttpMessageWriterFactory;
+import org.apache.hc.core5.http.util.Args;
 
 /**
  * Default implementation of {@link HttpClientConnection}.

Modified: httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/DefaultBHttpClientConnectionFactory.java
URL: http://svn.apache.org/viewvc/httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/DefaultBHttpClientConnectionFactory.java?rev=1715545&r1=1715521&r2=1715545&view=diff
==============================================================================
--- httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/DefaultBHttpServerConnection.java (original)
+++ httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/DefaultBHttpServerConnection.java Sat Nov 21 16:52:56 2015
@@ -25,7 +25,7 @@
  *
  */
 
-package org.apache.http.impl;
+package org.apache.hc.core5.http.impl;
 
 import java.io.IOException;
 import java.io.OutputStream;
@@ -33,22 +33,22 @@ import java.net.Socket;
 import java.nio.charset.CharsetDecoder;
 import java.nio.charset.CharsetEncoder;
 
-import org.apache.http.HttpEntity;
-import org.apache.http.HttpException;
-import org.apache.http.HttpRequest;
-import org.apache.http.HttpResponse;
-import org.apache.http.HttpServerConnection;
-import org.apache.http.annotation.NotThreadSafe;
-import org.apache.http.config.MessageConstraints;
-import org.apache.http.entity.ContentLengthStrategy;
-import org.apache.http.impl.entity.DefaultContentLengthStrategy;
-import org.apache.http.impl.io.DefaultHttpRequestParserFactory;
-import org.apache.http.impl.io.DefaultHttpResponseWriterFactory;
-import org.apache.http.io.HttpMessageParser;
-import org.apache.http.io.HttpMessageParserFactory;
-import org.apache.http.io.HttpMessageWriter;
-import org.apache.http.io.HttpMessageWriterFactory;
-import org.apache.http.util.Args;
+import org.apache.hc.core5.http.HttpEntity;
+import org.apache.hc.core5.http.HttpException;
+import org.apache.hc.core5.http.HttpRequest;
+import org.apache.hc.core5.http.HttpResponse;
+import org.apache.hc.core5.http.HttpServerConnection;
+import org.apache.hc.core5.http.annotation.NotThreadSafe;
+import org.apache.hc.core5.http.config.MessageConstraints;
+import org.apache.hc.core5.http.entity.ContentLengthStrategy;
+import org.apache.hc.core5.http.impl.entity.DefaultContentLengthStrategy;
+import org.apache.hc.core5.http.impl.io.DefaultHttpRequestParserFactory;
+import org.apache.hc.core5.http.impl.io.DefaultHttpResponseWriterFactory;
+import org.apache.hc.core5.http.io.HttpMessageParser;
+import org.apache.hc.core5.http.io.HttpMessageParserFactory;
+import org.apache.hc.core5.http.io.HttpMessageWriter;
+import org.apache.hc.core5.http.io.HttpMessageWriterFactory;
+import org.apache.hc.core5.http.util.Args;
 
 /**
  * Default implementation of {@link HttpServerConnection}.

Modified: httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/DefaultBHttpServerConnectionFactory.java
URL: http://svn.apache.org/viewvc/httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/DefaultBHttpServerConnectionFactory.java?rev=1715545&r1=1715521&r2=1715545&view=diff
==============================================================================
--- httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/DefaultConnectionReuseStrategy.java (original)
+++ httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/DefaultConnectionReuseStrategy.java Sat Nov 21 16:52:56 2015
@@ -25,24 +25,24 @@
  *
  */
 
-package org.apache.http.impl;
+package org.apache.hc.core5.http.impl;
 
 import java.util.Iterator;
 
-import org.apache.http.ConnectionReuseStrategy;
-import org.apache.http.Header;
-import org.apache.http.HeaderElements;
-import org.apache.http.HttpHeaders;
-import org.apache.http.HttpRequest;
-import org.apache.http.HttpResponse;
-import org.apache.http.HttpStatus;
-import org.apache.http.HttpVersion;
-import org.apache.http.ProtocolVersion;
-import org.apache.http.annotation.Immutable;
-import org.apache.http.message.BasicHeaderIterator;
-import org.apache.http.message.BasicTokenIterator;
-import org.apache.http.protocol.HttpContext;
-import org.apache.http.util.Args;
+import org.apache.hc.core5.http.ConnectionReuseStrategy;
+import org.apache.hc.core5.http.Header;
+import org.apache.hc.core5.http.HeaderElements;
+import org.apache.hc.core5.http.HttpHeaders;
+import org.apache.hc.core5.http.HttpRequest;
+import org.apache.hc.core5.http.HttpResponse;
+import org.apache.hc.core5.http.HttpStatus;
+import org.apache.hc.core5.http.HttpVersion;
+import org.apache.hc.core5.http.ProtocolVersion;
+import org.apache.hc.core5.http.annotation.Immutable;
+import org.apache.hc.core5.http.message.BasicHeaderIterator;
+import org.apache.hc.core5.http.message.BasicTokenIterator;
+import org.apache.hc.core5.http.protocol.HttpContext;
+import org.apache.hc.core5.http.util.Args;
 
 /**
  * Default implementation of a strategy deciding about connection re-use. The strategy

Modified: httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/DefaultHttpRequestFactory.java
URL: http://svn.apache.org/viewvc/httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/DefaultHttpRequestFactory.java?rev=1715545&r1=1715521&r2=1715545&view=diff
==============================================================================
--- httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/DefaultHttpRequestFactory.java (original)
+++ httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/DefaultHttpRequestFactory.java Sat Nov 21 16:52:56 2015
@@ -25,15 +25,15 @@
  *
  */
 
-package org.apache.http.impl;
+package org.apache.hc.core5.http.impl;
 
-import org.apache.http.HttpRequest;
-import org.apache.http.HttpRequestFactory;
-import org.apache.http.MethodNotSupportedException;
-import org.apache.http.RequestLine;
-import org.apache.http.annotation.Immutable;
-import org.apache.http.message.BasicHttpRequest;
-import org.apache.http.util.Args;
+import org.apache.hc.core5.http.HttpRequest;
+import org.apache.hc.core5.http.HttpRequestFactory;
+import org.apache.hc.core5.http.MethodNotSupportedException;
+import org.apache.hc.core5.http.RequestLine;
+import org.apache.hc.core5.http.annotation.Immutable;
+import org.apache.hc.core5.http.message.BasicHttpRequest;
+import org.apache.hc.core5.http.util.Args;
 
 /**
  * Default factory for creating {@link HttpRequest} objects.

Modified: httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/DefaultHttpResponseFactory.java
URL: http://svn.apache.org/viewvc/httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/DefaultHttpResponseFactory.java?rev=1715545&r1=1715521&r2=1715545&view=diff
==============================================================================
--- httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/DefaultHttpResponseFactory.java (original)
+++ httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/DefaultHttpResponseFactory.java Sat Nov 21 16:52:56 2015
@@ -25,20 +25,20 @@
  *
  */
 
-package org.apache.http.impl;
+package org.apache.hc.core5.http.impl;
 
 import java.util.Locale;
 
-import org.apache.http.HttpResponse;
-import org.apache.http.HttpResponseFactory;
-import org.apache.http.HttpVersion;
-import org.apache.http.ReasonPhraseCatalog;
-import org.apache.http.StatusLine;
-import org.apache.http.annotation.Immutable;
-import org.apache.http.message.BasicHttpResponse;
-import org.apache.http.message.BasicStatusLine;
-import org.apache.http.protocol.HttpContext;
-import org.apache.http.util.Args;
+import org.apache.hc.core5.http.HttpResponse;
+import org.apache.hc.core5.http.HttpResponseFactory;
+import org.apache.hc.core5.http.HttpVersion;
+import org.apache.hc.core5.http.ReasonPhraseCatalog;
+import org.apache.hc.core5.http.StatusLine;
+import org.apache.hc.core5.http.annotation.Immutable;
+import org.apache.hc.core5.http.message.BasicHttpResponse;
+import org.apache.hc.core5.http.message.BasicStatusLine;
+import org.apache.hc.core5.http.protocol.HttpContext;
+import org.apache.hc.core5.http.util.Args;
 
 /**
  * Default factory for creating {@link HttpResponse} objects.

Modified: httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/EnglishReasonPhraseCatalog.java
URL: http://svn.apache.org/viewvc/httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/EnglishReasonPhraseCatalog.java?rev=1715545&r1=1715521&r2=1715545&view=diff
==============================================================================
--- httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/EnglishReasonPhraseCatalog.java (original)
+++ httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/EnglishReasonPhraseCatalog.java Sat Nov 21 16:52:56 2015
@@ -25,14 +25,14 @@
  *
  */
 
-package org.apache.http.impl;
+package org.apache.hc.core5.http.impl;
 
 import java.util.Locale;
 
-import org.apache.http.HttpStatus;
-import org.apache.http.ReasonPhraseCatalog;
-import org.apache.http.annotation.Immutable;
-import org.apache.http.util.Args;
+import org.apache.hc.core5.http.HttpStatus;
+import org.apache.hc.core5.http.ReasonPhraseCatalog;
+import org.apache.hc.core5.http.annotation.Immutable;
+import org.apache.hc.core5.http.util.Args;
 
 /**
  * English reason phrases for HTTP status codes.

Modified: httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/HttpConnectionMetricsImpl.java
URL: http://svn.apache.org/viewvc/httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/HttpConnectionMetricsImpl.java?rev=1715545&r1=1715521&r2=1715545&view=diff
==============================================================================
--- httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/HttpConnectionMetricsImpl.java (original)
+++ httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/HttpConnectionMetricsImpl.java Sat Nov 21 16:52:56 2015
@@ -25,14 +25,14 @@
  *
  */
 
-package org.apache.http.impl;
+package org.apache.hc.core5.http.impl;
 
 import java.util.HashMap;
 import java.util.Map;
 
-import org.apache.http.HttpConnectionMetrics;
-import org.apache.http.annotation.NotThreadSafe;
-import org.apache.http.io.HttpTransportMetrics;
+import org.apache.hc.core5.http.HttpConnectionMetrics;
+import org.apache.hc.core5.http.annotation.NotThreadSafe;
+import org.apache.hc.core5.http.io.HttpTransportMetrics;
 
 /**
  * Default implementation of the {@link HttpConnectionMetrics} interface.

Modified: httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/IncomingHttpEntity.java
URL: http://svn.apache.org/viewvc/httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/IncomingHttpEntity.java?rev=1715545&r1=1715521&r2=1715545&view=diff
==============================================================================
--- httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/IncomingHttpEntity.java (original)
+++ httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/IncomingHttpEntity.java Sat Nov 21 16:52:56 2015
@@ -25,18 +25,18 @@
  *
  */
 
-package org.apache.http.impl;
+package org.apache.hc.core5.http.impl;
 
 import java.io.IOException;
 import java.io.InputStream;
 import java.util.Collections;
 import java.util.Set;
 
-import org.apache.http.Header;
-import org.apache.http.TrailerSupplier;
-import org.apache.http.annotation.NotThreadSafe;
-import org.apache.http.entity.AbstractImmutableHttpEntity;
-import org.apache.http.impl.io.EmptyInputStream;
+import org.apache.hc.core5.http.Header;
+import org.apache.hc.core5.http.TrailerSupplier;
+import org.apache.hc.core5.http.annotation.NotThreadSafe;
+import org.apache.hc.core5.http.entity.AbstractImmutableHttpEntity;
+import org.apache.hc.core5.http.impl.io.EmptyInputStream;
 
 /**
  * Represents entity received from an open connection.

Modified: httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/bootstrap/HttpServer.java
URL: http://svn.apache.org/viewvc/httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/bootstrap/HttpServer.java?rev=1715545&r1=1715521&r2=1715545&view=diff
==============================================================================
--- httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/bootstrap/HttpServer.java (original)
+++ httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/bootstrap/HttpServer.java Sat Nov 21 16:52:56 2015
@@ -24,7 +24,7 @@
  * <http://www.apache.org/>.
  *
  */
-package org.apache.http.impl.bootstrap;
+package org.apache.hc.core5.http.impl.bootstrap;
 
 import java.io.IOException;
 import java.net.InetAddress;
@@ -38,12 +38,12 @@ import java.util.concurrent.atomic.Atomi
 import javax.net.ServerSocketFactory;
 import javax.net.ssl.SSLServerSocket;
 
-import org.apache.http.ExceptionLogger;
-import org.apache.http.HttpConnectionFactory;
-import org.apache.http.HttpServerConnection;
-import org.apache.http.config.SocketConfig;
-import org.apache.http.impl.DefaultBHttpServerConnection;
-import org.apache.http.protocol.HttpService;
+import org.apache.hc.core5.http.ExceptionLogger;
+import org.apache.hc.core5.http.HttpConnectionFactory;
+import org.apache.hc.core5.http.HttpServerConnection;
+import org.apache.hc.core5.http.config.SocketConfig;
+import org.apache.hc.core5.http.impl.DefaultBHttpServerConnection;
+import org.apache.hc.core5.http.protocol.HttpService;
 
 /**
  * @since 4.4

Modified: httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/bootstrap/RequestListener.java
URL: http://svn.apache.org/viewvc/httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/bootstrap/RequestListener.java?rev=1715545&r1=1715521&r2=1715545&view=diff
==============================================================================
--- httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/bootstrap/RequestListener.java (original)
+++ httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/bootstrap/RequestListener.java Sat Nov 21 16:52:56 2015
@@ -24,7 +24,7 @@
  * <http://www.apache.org/>.
  *
  */
-package org.apache.http.impl.bootstrap;
+package org.apache.hc.core5.http.impl.bootstrap;
 
 import java.io.IOException;
 import java.net.ServerSocket;
@@ -32,11 +32,11 @@ import java.net.Socket;
 import java.util.concurrent.ExecutorService;
 import java.util.concurrent.atomic.AtomicBoolean;
 
-import org.apache.http.ExceptionLogger;
-import org.apache.http.HttpConnectionFactory;
-import org.apache.http.HttpServerConnection;
-import org.apache.http.config.SocketConfig;
-import org.apache.http.protocol.HttpService;
+import org.apache.hc.core5.http.ExceptionLogger;
+import org.apache.hc.core5.http.HttpConnectionFactory;
+import org.apache.hc.core5.http.HttpServerConnection;
+import org.apache.hc.core5.http.config.SocketConfig;
+import org.apache.hc.core5.http.protocol.HttpService;
 
 /**
  * @since 4.4

Modified: httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/bootstrap/SSLServerSetupHandler.java
URL: http://svn.apache.org/viewvc/httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/bootstrap/SSLServerSetupHandler.java?rev=1715545&r1=1715521&r2=1715545&view=diff
==============================================================================
--- httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/bootstrap/SSLServerSetupHandler.java (original)
+++ httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/bootstrap/SSLServerSetupHandler.java Sat Nov 21 16:52:56 2015
@@ -24,7 +24,7 @@
  * <http://www.apache.org/>.
  *
  */
-package org.apache.http.impl.bootstrap;
+package org.apache.hc.core5.http.impl.bootstrap;
 
 import javax.net.ssl.SSLException;
 import javax.net.ssl.SSLServerSocket;

Modified: httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/bootstrap/ServerBootstrap.java
URL: http://svn.apache.org/viewvc/httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/bootstrap/ServerBootstrap.java?rev=1715545&r1=1715521&r2=1715545&view=diff
==============================================================================
--- httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/bootstrap/ThreadFactoryImpl.java (original)
+++ httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/bootstrap/ThreadFactoryImpl.java Sat Nov 21 16:52:56 2015
@@ -24,7 +24,7 @@
  * <http://www.apache.org/>.
  *
  */
-package org.apache.http.impl.bootstrap;
+package org.apache.hc.core5.http.impl.bootstrap;
 
 import java.util.concurrent.ThreadFactory;
 import java.util.concurrent.atomic.AtomicLong;

Modified: httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/bootstrap/Worker.java
URL: http://svn.apache.org/viewvc/httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/bootstrap/Worker.java?rev=1715545&r1=1715521&r2=1715545&view=diff
==============================================================================
--- httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/bootstrap/Worker.java (original)
+++ httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/bootstrap/Worker.java Sat Nov 21 16:52:56 2015
@@ -24,15 +24,15 @@
  * <http://www.apache.org/>.
  *
  */
-package org.apache.http.impl.bootstrap;
+package org.apache.hc.core5.http.impl.bootstrap;
 
 import java.io.IOException;
 
-import org.apache.http.ExceptionLogger;
-import org.apache.http.HttpServerConnection;
-import org.apache.http.protocol.BasicHttpContext;
-import org.apache.http.protocol.HttpCoreContext;
-import org.apache.http.protocol.HttpService;
+import org.apache.hc.core5.http.ExceptionLogger;
+import org.apache.hc.core5.http.HttpServerConnection;
+import org.apache.hc.core5.http.protocol.BasicHttpContext;
+import org.apache.hc.core5.http.protocol.HttpCoreContext;
+import org.apache.hc.core5.http.protocol.HttpService;
 
 /**
  * @since 4.4

Modified: httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/bootstrap/package-info.java
URL: http://svn.apache.org/viewvc/httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/bootstrap/package-info.java?rev=1715545&r1=1715521&r2=1715545&view=diff
==============================================================================
--- httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/bootstrap/package-info.java (original)
+++ httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/bootstrap/package-info.java Sat Nov 21 16:52:56 2015
@@ -28,4 +28,4 @@
 /**
  * Embedded server and server bootstrap.
  */
-package org.apache.http.impl.bootstrap;
+package org.apache.hc.core5.http.impl.bootstrap;

Modified: httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/entity/DefaultContentLengthStrategy.java
URL: http://svn.apache.org/viewvc/httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/entity/DefaultContentLengthStrategy.java?rev=1715545&r1=1715521&r2=1715545&view=diff
==============================================================================
--- httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/entity/DefaultContentLengthStrategy.java (original)
+++ httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/entity/DefaultContentLengthStrategy.java Sat Nov 21 16:52:56 2015
@@ -25,18 +25,18 @@
  *
  */
 
-package org.apache.http.impl.entity;
+package org.apache.hc.core5.http.impl.entity;
 
-import org.apache.http.Header;
-import org.apache.http.HeaderElements;
-import org.apache.http.HttpException;
-import org.apache.http.HttpHeaders;
-import org.apache.http.HttpMessage;
-import org.apache.http.NotImplementedException;
-import org.apache.http.ProtocolException;
-import org.apache.http.annotation.Immutable;
-import org.apache.http.entity.ContentLengthStrategy;
-import org.apache.http.util.Args;
+import org.apache.hc.core5.http.Header;
+import org.apache.hc.core5.http.HeaderElements;
+import org.apache.hc.core5.http.HttpException;
+import org.apache.hc.core5.http.HttpHeaders;
+import org.apache.hc.core5.http.HttpMessage;
+import org.apache.hc.core5.http.NotImplementedException;
+import org.apache.hc.core5.http.ProtocolException;
+import org.apache.hc.core5.http.annotation.Immutable;
+import org.apache.hc.core5.http.entity.ContentLengthStrategy;
+import org.apache.hc.core5.http.util.Args;
 
 /**
  * The default implementation of the content length strategy. This class

Modified: httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/entity/package-info.java
URL: http://svn.apache.org/viewvc/httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/entity/package-info.java?rev=1715545&r1=1715521&r2=1715545&view=diff
==============================================================================
--- httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/entity/package-info.java (original)
+++ httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/entity/package-info.java Sat Nov 21 16:52:56 2015
@@ -28,4 +28,4 @@
 /**
  * Default implementations of entity content strategies.
  */
-package org.apache.http.impl.entity;
+package org.apache.hc.core5.http.impl.entity;

Modified: httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/io/AbstractMessageParser.java
URL: http://svn.apache.org/viewvc/httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/io/AbstractMessageParser.java?rev=1715545&r1=1715521&r2=1715545&view=diff
==============================================================================
--- httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/io/ChunkedInputStream.java (original)
+++ httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/io/ChunkedInputStream.java Sat Nov 21 16:52:56 2015
@@ -25,21 +25,21 @@
  *
  */
 
-package org.apache.http.impl.io;
+package org.apache.hc.core5.http.impl.io;
 
 import java.io.IOException;
 import java.io.InputStream;
 
-import org.apache.http.ConnectionClosedException;
-import org.apache.http.Header;
-import org.apache.http.HttpException;
-import org.apache.http.MalformedChunkCodingException;
-import org.apache.http.TruncatedChunkException;
-import org.apache.http.annotation.NotThreadSafe;
-import org.apache.http.config.MessageConstraints;
-import org.apache.http.io.SessionInputBuffer;
-import org.apache.http.util.Args;
-import org.apache.http.util.CharArrayBuffer;
+import org.apache.hc.core5.http.ConnectionClosedException;
+import org.apache.hc.core5.http.Header;
+import org.apache.hc.core5.http.HttpException;
+import org.apache.hc.core5.http.MalformedChunkCodingException;
+import org.apache.hc.core5.http.TruncatedChunkException;
+import org.apache.hc.core5.http.annotation.NotThreadSafe;
+import org.apache.hc.core5.http.config.MessageConstraints;
+import org.apache.hc.core5.http.io.SessionInputBuffer;
+import org.apache.hc.core5.http.util.Args;
+import org.apache.hc.core5.http.util.CharArrayBuffer;
 
 /**
  * Implements chunked transfer coding. The content is received in small chunks.

Modified: httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/io/ChunkedOutputStream.java
URL: http://svn.apache.org/viewvc/httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/io/ChunkedOutputStream.java?rev=1715545&r1=1715521&r2=1715545&view=diff
==============================================================================
--- httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/io/ChunkedOutputStream.java (original)
+++ httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/io/ChunkedOutputStream.java Sat Nov 21 16:52:56 2015
@@ -25,18 +25,18 @@
  *
  */
 
-package org.apache.http.impl.io;
+package org.apache.hc.core5.http.impl.io;
 
 import java.io.IOException;
 import java.io.OutputStream;
 
-import org.apache.http.FormattedHeader;
-import org.apache.http.Header;
-import org.apache.http.TrailerSupplier;
-import org.apache.http.annotation.NotThreadSafe;
-import org.apache.http.io.SessionOutputBuffer;
-import org.apache.http.message.BasicLineFormatter;
-import org.apache.http.util.CharArrayBuffer;
+import org.apache.hc.core5.http.FormattedHeader;
+import org.apache.hc.core5.http.Header;
+import org.apache.hc.core5.http.TrailerSupplier;
+import org.apache.hc.core5.http.annotation.NotThreadSafe;
+import org.apache.hc.core5.http.io.SessionOutputBuffer;
+import org.apache.hc.core5.http.message.BasicLineFormatter;
+import org.apache.hc.core5.http.util.CharArrayBuffer;
 
 /**
  * Implements chunked transfer coding. The content is sent in small chunks.

Modified: httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/io/ContentLengthInputStream.java
URL: http://svn.apache.org/viewvc/httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/io/ContentLengthInputStream.java?rev=1715545&r1=1715521&r2=1715545&view=diff
==============================================================================
--- httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/io/ContentLengthInputStream.java (original)
+++ httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/io/ContentLengthInputStream.java Sat Nov 21 16:52:56 2015
@@ -25,15 +25,15 @@
  *
  */
 
-package org.apache.http.impl.io;
+package org.apache.hc.core5.http.impl.io;
 
 import java.io.IOException;
 import java.io.InputStream;
 
-import org.apache.http.ConnectionClosedException;
-import org.apache.http.annotation.NotThreadSafe;
-import org.apache.http.io.SessionInputBuffer;
-import org.apache.http.util.Args;
+import org.apache.hc.core5.http.ConnectionClosedException;
+import org.apache.hc.core5.http.annotation.NotThreadSafe;
+import org.apache.hc.core5.http.io.SessionInputBuffer;
+import org.apache.hc.core5.http.util.Args;
 
 /**
  * Input stream that cuts off after a defined number of bytes. This class
--- httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/entity/StringEntity.java (original)
+++ httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/entity/StringEntity.java Sat Nov 21 16:52:56 2015
@@ -25,7 +25,7 @@
  *
  */
 
-package org.apache.http.entity;
+package org.apache.hc.core5.http.entity;
 
 import java.io.ByteArrayInputStream;
 import java.io.IOException;
@@ -33,9 +33,9 @@ import java.io.InputStream;
 import java.io.OutputStream;
 import java.nio.charset.Charset;
 
-import org.apache.http.Consts;
-import org.apache.http.annotation.NotThreadSafe;
-import org.apache.http.util.Args;
+import org.apache.hc.core5.http.Consts;
+import org.apache.hc.core5.http.annotation.NotThreadSafe;
+import org.apache.hc.core5.http.util.Args;
 
 /**
  * A self contained, repeatable entity that obtains its content from
@@ -78,7 +78,7 @@ public class StringEntity extends Abstra
      *
      * @param string content to be used. Not {@code null}.
      * @param charset character set to be used. May be {@code null}, in which case the default
      *   is {@link org.apache.http.Consts#ISO_8859_1} is assumed
      *
      * @throws IllegalArgumentException if the string parameter is null
      *
@@ -78,7 +78,7 @@ public class StringEntity extends Abstra
      * @param string content to be used. Not {@code null}.
      * @param charset character set to be used. May be {@code null}, in which case the default
-     *   is {@link org.apache.http.Consts#ISO_8859_1} is assumed
+     *   is {@link org.apache.hc.core5.http.Consts#ISO_8859_1} is assumed
      *
      * @throws IllegalArgumentException if the string parameter is null

Modified: httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/entity/package-info.java
URL: http://svn.apache.org/viewvc/httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/entity/package-info.java?rev=1715545&r1=1715521&r2=1715545&view=diff
==============================================================================
--- httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/DefaultBHttpClientConnectionFactory.java (original)
+++ httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/DefaultBHttpClientConnectionFactory.java Sat Nov 21 16:52:56 2015
@@ -25,22 +25,22 @@
  *
  */
 
-package org.apache.http.impl;
+package org.apache.hc.core5.http.impl;
 
-import org.apache.http.HttpConnectionFactory;
-import org.apache.http.HttpRequest;
-import org.apache.http.HttpResponse;
-import org.apache.http.annotation.Immutable;
-import org.apache.http.config.ConnectionConfig;
-import org.apache.http.entity.ContentLengthStrategy;
-import org.apache.http.io.HttpMessageParserFactory;
-import org.apache.http.io.HttpMessageWriterFactory;
+import org.apache.hc.core5.http.HttpConnectionFactory;
+import org.apache.hc.core5.http.HttpRequest;
+import org.apache.hc.core5.http.HttpResponse;
+import org.apache.hc.core5.http.annotation.Immutable;
+import org.apache.hc.core5.http.config.ConnectionConfig;
+import org.apache.hc.core5.http.entity.ContentLengthStrategy;
+import org.apache.hc.core5.http.io.HttpMessageParserFactory;
+import org.apache.hc.core5.http.io.HttpMessageWriterFactory;
 
 import java.io.IOException;
 import java.net.Socket;
 
 /**
  * Default factory for {@link org.apache.http.HttpClientConnection}s.
  *
  * @since 4.3
  */
@@ -25,22 +25,22 @@
 
 /**
- * Default factory for {@link org.apache.http.HttpClientConnection}s.
+ * Default factory for {@link org.apache.hc.core5.http.HttpClientConnection}s.
  *
  * @since 4.3

Modified: httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/DefaultBHttpServerConnection.java
URL: http://svn.apache.org/viewvc/httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/DefaultBHttpServerConnection.java?rev=1715545&r1=1715521&r2=1715545&view=diff
==============================================================================
--- httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/DefaultBHttpServerConnectionFactory.java (original)
+++ httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/DefaultBHttpServerConnectionFactory.java Sat Nov 21 16:52:56 2015
@@ -25,22 +25,22 @@
  *
  */
 
-package org.apache.http.impl;
+package org.apache.hc.core5.http.impl;
 
-import org.apache.http.HttpConnectionFactory;
-import org.apache.http.HttpRequest;
-import org.apache.http.HttpResponse;
-import org.apache.http.annotation.Immutable;
-import org.apache.http.config.ConnectionConfig;
-import org.apache.http.entity.ContentLengthStrategy;
-import org.apache.http.io.HttpMessageParserFactory;
-import org.apache.http.io.HttpMessageWriterFactory;
+import org.apache.hc.core5.http.HttpConnectionFactory;
+import org.apache.hc.core5.http.HttpRequest;
+import org.apache.hc.core5.http.HttpResponse;
+import org.apache.hc.core5.http.annotation.Immutable;
+import org.apache.hc.core5.http.config.ConnectionConfig;
+import org.apache.hc.core5.http.entity.ContentLengthStrategy;
+import org.apache.hc.core5.http.io.HttpMessageParserFactory;
+import org.apache.hc.core5.http.io.HttpMessageWriterFactory;
 
 import java.io.IOException;
 import java.net.Socket;
 
 /**
  * Default factory for {@link org.apache.http.HttpServerConnection}s.
  *
  * @since 4.3
  */
@@ -25,22 +25,22 @@
 
 /**
- * Default factory for {@link org.apache.http.HttpServerConnection}s.
+ * Default factory for {@link org.apache.hc.core5.http.HttpServerConnection}s.
  *
  * @since 4.3

Modified: httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/DefaultConnectionReuseStrategy.java
URL: http://svn.apache.org/viewvc/httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/DefaultConnectionReuseStrategy.java?rev=1715545&r1=1715521&r2=1715545&view=diff
==============================================================================
--- httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/bootstrap/ServerBootstrap.java (original)
+++ httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/bootstrap/ServerBootstrap.java Sat Nov 21 16:52:56 2015
@@ -24,7 +24,7 @@
  * <http://www.apache.org/>.
  *
  */
-package org.apache.http.impl.bootstrap;
+package org.apache.hc.core5.http.impl.bootstrap;
 
 import java.net.InetAddress;
 import java.util.HashMap;
@@ -34,30 +34,30 @@ import java.util.Map;
 import javax.net.ServerSocketFactory;
 import javax.net.ssl.SSLContext;
 
-import org.apache.http.ConnectionReuseStrategy;
-import org.apache.http.ExceptionLogger;
-import org.apache.http.HttpConnectionFactory;
-import org.apache.http.HttpRequestInterceptor;
-import org.apache.http.HttpResponseFactory;
-import org.apache.http.HttpResponseInterceptor;
-import org.apache.http.config.ConnectionConfig;
-import org.apache.http.config.SocketConfig;
-import org.apache.http.impl.DefaultBHttpServerConnection;
-import org.apache.http.impl.DefaultBHttpServerConnectionFactory;
-import org.apache.http.impl.DefaultConnectionReuseStrategy;
-import org.apache.http.impl.DefaultHttpResponseFactory;
-import org.apache.http.protocol.HttpExpectationVerifier;
-import org.apache.http.protocol.HttpProcessor;
-import org.apache.http.protocol.HttpProcessorBuilder;
-import org.apache.http.protocol.HttpRequestHandler;
-import org.apache.http.protocol.HttpRequestHandlerMapper;
-import org.apache.http.protocol.HttpService;
-import org.apache.http.protocol.RequestValidateHost;
-import org.apache.http.protocol.ResponseConnControl;
-import org.apache.http.protocol.ResponseContent;
-import org.apache.http.protocol.ResponseDate;
-import org.apache.http.protocol.ResponseServer;
-import org.apache.http.protocol.UriHttpRequestHandlerMapper;
+import org.apache.hc.core5.http.ConnectionReuseStrategy;
+import org.apache.hc.core5.http.ExceptionLogger;
+import org.apache.hc.core5.http.HttpConnectionFactory;
+import org.apache.hc.core5.http.HttpRequestInterceptor;
+import org.apache.hc.core5.http.HttpResponseFactory;
+import org.apache.hc.core5.http.HttpResponseInterceptor;
+import org.apache.hc.core5.http.config.ConnectionConfig;
+import org.apache.hc.core5.http.config.SocketConfig;
+import org.apache.hc.core5.http.impl.DefaultBHttpServerConnection;
+import org.apache.hc.core5.http.impl.DefaultBHttpServerConnectionFactory;
+import org.apache.hc.core5.http.impl.DefaultConnectionReuseStrategy;
+import org.apache.hc.core5.http.impl.DefaultHttpResponseFactory;
+import org.apache.hc.core5.http.protocol.HttpExpectationVerifier;
+import org.apache.hc.core5.http.protocol.HttpProcessor;
+import org.apache.hc.core5.http.protocol.HttpProcessorBuilder;
+import org.apache.hc.core5.http.protocol.HttpRequestHandler;
+import org.apache.hc.core5.http.protocol.HttpRequestHandlerMapper;
+import org.apache.hc.core5.http.protocol.HttpService;
+import org.apache.hc.core5.http.protocol.RequestValidateHost;
+import org.apache.hc.core5.http.protocol.ResponseConnControl;
+import org.apache.hc.core5.http.protocol.ResponseContent;
+import org.apache.hc.core5.http.protocol.ResponseDate;
+import org.apache.hc.core5.http.protocol.ResponseServer;
+import org.apache.hc.core5.http.protocol.UriHttpRequestHandlerMapper;
 
 /**
  * @since 4.4
@@ -120,7 +120,7 @@ public class ServerBootstrap {
      * Sets connection configuration.
      * <p>
      * Please note this value can be overridden by the {@link #setConnectionFactory(
-     * org.apache.http.HttpConnectionFactory)} method.
+     * org.apache.hc.core5.http.HttpConnectionFactory)} method.
      */
     public final ServerBootstrap setConnectionConfig(final ConnectionConfig connectionConfig) {
         this.connectionConfig = connectionConfig;
@@ -139,7 +139,7 @@ public class ServerBootstrap {
      * Adds this protocol interceptor to the head of the protocol processing list.
      * <p>
      * Please note this value can be overridden by the {@link #setHttpProcessor(
-     * org.apache.http.protocol.HttpProcessor)} method.
+     * org.apache.hc.core5.http.protocol.HttpProcessor)} method.
      */
     public final ServerBootstrap addInterceptorFirst(final HttpResponseInterceptor itcp) {
         if (itcp == null) {
@@ -156,7 +156,7 @@ public class ServerBootstrap {
      * Adds this protocol interceptor to the tail of the protocol processing list.
      * <p>
      * Please note this value can be overridden by the {@link #setHttpProcessor(
-     * org.apache.http.protocol.HttpProcessor)} method.
+     * org.apache.hc.core5.http.protocol.HttpProcessor)} method.
      */
     public final ServerBootstrap addInterceptorLast(final HttpResponseInterceptor itcp) {
         if (itcp == null) {
@@ -173,7 +173,7 @@ public class ServerBootstrap {
      * Adds this protocol interceptor to the head of the protocol processing list.
      * <p>
      * Please note this value can be overridden by the {@link #setHttpProcessor(
-     * org.apache.http.protocol.HttpProcessor)} method.
+     * org.apache.hc.core5.http.protocol.HttpProcessor)} method.
      */
     public final ServerBootstrap addInterceptorFirst(final HttpRequestInterceptor itcp) {
         if (itcp == null) {
@@ -190,7 +190,7 @@ public class ServerBootstrap {
      * Adds this protocol interceptor to the tail of the protocol processing list.
      * <p>
      * Please note this value can be overridden by the {@link #setHttpProcessor(
-     * org.apache.http.protocol.HttpProcessor)} method.
+     * org.apache.hc.core5.http.protocol.HttpProcessor)} method.
      */
     public final ServerBootstrap addInterceptorLast(final HttpRequestInterceptor itcp) {
         if (itcp == null) {
@@ -207,7 +207,7 @@ public class ServerBootstrap {
      * Assigns {@code Server} response header value.
      * <p>
      * Please note this value can be overridden by the {@link #setHttpProcessor(
-     * org.apache.http.protocol.HttpProcessor)} method.
+     * org.apache.hc.core5.http.protocol.HttpProcessor)} method.
      */
     public final ServerBootstrap setServerInfo(final String serverInfo) {
         this.serverInfo = serverInfo;
@@ -243,7 +243,7 @@ public class ServerBootstrap {
      * matching the given pattern.
      * <p>
      * Please note this value can be overridden by the {@link #setHandlerMapper(
-     *   org.apache.http.protocol.HttpRequestHandlerMapper)} method.
+     *   org.apache.hc.core5.http.protocol.HttpRequestHandlerMapper)} method.
      *
      * @param pattern the pattern to register the handler for.
      * @param handler the handler.
@@ -277,7 +277,7 @@ public class ServerBootstrap {
     }
 
     /**
      * Assigns {@link org.apache.http.impl.bootstrap.SSLServerSetupHandler} instance.
      */
     public final ServerBootstrap setSslSetupHandler(final SSLServerSetupHandler sslSetupHandler) {
         this.sslSetupHandler = sslSetupHandler;
@@ -304,7 +304,7 @@ public class ServerBootstrap {
     }
 
     /**
      * Assigns {@link org.apache.http.ExceptionLogger} instance.
      */
     public final ServerBootstrap setExceptionLogger(final ExceptionLogger exceptionLogger) {
         this.exceptionLogger = exceptionLogger;
@@ -277,7 +277,7 @@ public class ServerBootstrap {
 
     /**
-     * Assigns {@link org.apache.http.impl.bootstrap.SSLServerSetupHandler} instance.
+     * Assigns {@link org.apache.hc.core5.http.impl.bootstrap.SSLServerSetupHandler} instance.
      */
     public final ServerBootstrap setSslSetupHandler(final SSLServerSetupHandler sslSetupHandler) {
@@ -304,7 +304,7 @@ public class ServerBootstrap {
 
     /**
-     * Assigns {@link org.apache.http.ExceptionLogger} instance.
+     * Assigns {@link org.apache.hc.core5.http.ExceptionLogger} instance.
      */
     public final ServerBootstrap setExceptionLogger(final ExceptionLogger exceptionLogger) {

Modified: httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/bootstrap/ThreadFactoryImpl.java
URL: http://svn.apache.org/viewvc/httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/bootstrap/ThreadFactoryImpl.java?rev=1715545&r1=1715521&r2=1715545&view=diff
==============================================================================
--- httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/io/AbstractMessageParser.java (original)
+++ httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/io/AbstractMessageParser.java Sat Nov 21 16:52:56 2015
@@ -25,28 +25,28 @@
  *
  */
 
-package org.apache.http.impl.io;
+package org.apache.hc.core5.http.impl.io;
 
 import java.io.IOException;
 import java.util.ArrayList;
 import java.util.List;
 
-import org.apache.http.Header;
-import org.apache.http.HttpException;
-import org.apache.http.HttpMessage;
-import org.apache.http.MessageConstraintException;
-import org.apache.http.annotation.NotThreadSafe;
-import org.apache.http.config.MessageConstraints;
-import org.apache.http.io.HttpMessageParser;
-import org.apache.http.io.SessionInputBuffer;
-import org.apache.http.message.LazyLineParser;
-import org.apache.http.message.LineParser;
-import org.apache.http.util.Args;
-import org.apache.http.util.CharArrayBuffer;
+import org.apache.hc.core5.http.Header;
+import org.apache.hc.core5.http.HttpException;
+import org.apache.hc.core5.http.HttpMessage;
+import org.apache.hc.core5.http.MessageConstraintException;
+import org.apache.hc.core5.http.annotation.NotThreadSafe;
+import org.apache.hc.core5.http.config.MessageConstraints;
+import org.apache.hc.core5.http.io.HttpMessageParser;
+import org.apache.hc.core5.http.io.SessionInputBuffer;
+import org.apache.hc.core5.http.message.LazyLineParser;
+import org.apache.hc.core5.http.message.LineParser;
+import org.apache.hc.core5.http.util.Args;
+import org.apache.hc.core5.http.util.CharArrayBuffer;
 
 /**
  * Abstract base class for HTTP message parsers that obtain input from
  * an instance of {@link org.apache.http.io.SessionInputBuffer}.
  *
  * @since 4.0
  */
@@ -68,7 +68,7 @@ public abstract class AbstractMessagePar
      * Creates new instance of AbstractMessageParser.
      *
      * @param lineParser the line parser. If {@code null}
      *   {@link org.apache.http.message.LazyLineParser#INSTANCE} will be used.
      * @param constraints the message constraints. If {@code null}
      *   {@link MessageConstraints#DEFAULT} will be used.
      *
@@ -101,7 +101,7 @@ public abstract class AbstractMessagePar
      *  value or zero will disable the check.
      * @return array of HTTP headers
      * @param lineParser the line parser. If {@code null}
      *   {@link org.apache.http.message.LazyLineParser#INSTANCE} will be used
      *
      * @throws IOException in case of an I/O error
      * @throws HttpException in case of HTTP protocol violation
@@ -25,28 +25,28 @@
 /**
  * Abstract base class for HTTP message parsers that obtain input from
- * an instance of {@link org.apache.http.io.SessionInputBuffer}.
+ * an instance of {@link org.apache.hc.core5.http.io.SessionInputBuffer}.
  *
  * @since 4.0
@@ -68,7 +68,7 @@ public abstract class AbstractMessagePar
      *
      * @param lineParser the line parser. If {@code null}
-     *   {@link org.apache.http.message.LazyLineParser#INSTANCE} will be used.
+     *   {@link org.apache.hc.core5.http.message.LazyLineParser#INSTANCE} will be used.
      * @param constraints the message constraints. If {@code null}
      *   {@link MessageConstraints#DEFAULT} will be used.
@@ -101,7 +101,7 @@ public abstract class AbstractMessagePar
      * @return array of HTTP headers
      * @param lineParser the line parser. If {@code null}
-     *   {@link org.apache.http.message.LazyLineParser#INSTANCE} will be used
+     *   {@link org.apache.hc.core5.http.message.LazyLineParser#INSTANCE} will be used
      *
      * @throws IOException in case of an I/O error

Modified: httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/io/AbstractMessageWriter.java
URL: http://svn.apache.org/viewvc/httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/io/AbstractMessageWriter.java?rev=1715545&r1=1715521&r2=1715545&view=diff
==============================================================================
--- httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/io/AbstractMessageWriter.java (original)
+++ httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/io/AbstractMessageWriter.java Sat Nov 21 16:52:56 2015
@@ -25,26 +25,26 @@
  *
  */
 
-package org.apache.http.impl.io;
+package org.apache.hc.core5.http.impl.io;
 
 import java.io.IOException;
 import java.util.Iterator;
 
-import org.apache.http.FormattedHeader;
-import org.apache.http.Header;
-import org.apache.http.HttpException;
-import org.apache.http.HttpMessage;
-import org.apache.http.annotation.NotThreadSafe;
-import org.apache.http.io.HttpMessageWriter;
-import org.apache.http.io.SessionOutputBuffer;
-import org.apache.http.message.BasicLineFormatter;
-import org.apache.http.message.LineFormatter;
-import org.apache.http.util.Args;
-import org.apache.http.util.CharArrayBuffer;
+import org.apache.hc.core5.http.FormattedHeader;
+import org.apache.hc.core5.http.Header;
+import org.apache.hc.core5.http.HttpException;
+import org.apache.hc.core5.http.HttpMessage;
+import org.apache.hc.core5.http.annotation.NotThreadSafe;
+import org.apache.hc.core5.http.io.HttpMessageWriter;
+import org.apache.hc.core5.http.io.SessionOutputBuffer;
+import org.apache.hc.core5.http.message.BasicLineFormatter;
+import org.apache.hc.core5.http.message.LineFormatter;
+import org.apache.hc.core5.http.util.Args;
+import org.apache.hc.core5.http.util.CharArrayBuffer;
 
 /**
  * Abstract base class for HTTP message writers that serialize output to
  * an instance of {@link org.apache.http.io.SessionOutputBuffer}.
  *
  * @since 4.0
  */
@@ -25,26 +25,26 @@
 /**
  * Abstract base class for HTTP message writers that serialize output to
- * an instance of {@link org.apache.http.io.SessionOutputBuffer}.
+ * an instance of {@link org.apache.hc.core5.http.io.SessionOutputBuffer}.
  *
  * @since 4.0

Modified: httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/io/ChunkedInputStream.java
URL: http://svn.apache.org/viewvc/httpcomponents/httpcore/trunk/httpcore/src/main/java/org/apache/hc/core5/http/impl/io/ChunkedInputStream.java?rev=1715545&r1=1715521&r2=1715545&view=diff
==============================================================================